---------------------------------------------------------------------------
--- capi: awesome C API
--
-- @author Julien Danjou &lt;julien@danjou.info&gt;
-- @copyright 2008 Julien Danjou
---------------------------------------------------------------------------
module("capi")
--- Client object.
-- @field name The client title.
-- @field skip_taskbar True if the client does not want to be in taskbar.
-- @field type The window type (desktop, normal, dock, …).
-- @field class The client class.
-- @field instance The client instance.
-- @field pid The client PID, if available.
-- @field role The window role, if available.
-- @field machine The machine client is running on.
-- @field icon_name The client name when iconified.
-- @field screen Client screen number.
-- @field hide Define if the client must be hidden, i.e. never mapped,
-- invisible in taskbar.
-- @field minimize Define it the client must be iconify, i.e. only visible in
-- taskbar.
-- @field icon_path Path to the icon used to identify.
-- @field floating True always floating.
-- @field honorsizehints Honor size hints, i.e. respect size ratio.
-- @field border_width The client border width.
-- @field border_color The client border color.
-- @field titlebar The client titlebar.
-- @field urgent The client urgent state.
-- @field focus The focused client.
-- @field opacity The client opacity between 0 and 1.
-- @field ontop The client is on top of every other windows.
-- @field fullscreen The client is fullscreen or not.
-- @field transient_for Return the client the window is transient for.
-- @field size_hints A table with size hints of the client: user_position,
--         user_size, program_position and program_size.
-- @class table
-- @name client
client
--- Get all clients into a table.
-- @param arg1 An optional screen nunmber.
-- @return A table with all clients.
function client.get()
end

--- Get only visible clients for a screen (DEPRECATED).
-- @param arg1 A screen number.
-- @return A table with all visible clients for this screen.
function client.visible_get()
end

--- Check if a client is visible on its screen.
-- @return A boolean value, true if the client is visible, false otherwise.
function client.isvisible()
end

--- Return client geometry.
-- @param arg1 A table with new coordinates, or none.
-- @return A table with client coordinates.
function client.geometry()
end

--- Return client geometry, using also titlebar and border width.
-- @param arg1 A table with new coordinates, or none.
-- @return A table with client coordinates.
function client.fullgeometry()
end

--- Get or set mouse buttons bindings for a client.
-- @param arg1 An array of mouse button bindings objects, or nothing.
function client.buttons()
end

--- Access or set the client tags.
-- @param arg1 A table with tags to set, or none to get the current tags table.
function client.tags()
end

--- Kill a client.
--
function client.kill()
end

--- Swap a client with another one.
-- @param arg1 A client to swap with.
function client.swap()
end

--- Raise a client on top of others which are on the same layer.
function client.raise()
end

--- Lower a client on bottom of others which are on the same layer.
function client.lower()
end

--- Redraw a client by unmapping and mapping it quickly.
--
function client.redraw()
end

--- Resize a client with mouse.
--
-- @param arg1 An optional table with keys: `corner', such as bottomleft,
-- topright, etc, to specify which corner to grab (default to auto) and
-- `infobox' to enable or disable the coordinates and dimensions box (default to
-- enabled).
function client.mouse_resize()
end

--- Move a client with mouse.
--
-- @param arg1 An optional table with keys: `snap' for pixel to snap (default to 8), and
-- `infobox' to enable or disable the coordinates and dimensions box (default to
-- enabled).
function client.mouse_move()
end

--- Stop managing a client.
function client.unmanage()
end

This function is not yet documented.

This function is not yet documented.

--- Define a global key binding. This key binding will always be available.
--
-- @param arg1 A table with modifier keys.
-- @param arg2 A key name.
-- @param arg3 A function to execute.
-- @return The keybinding.
function keybinding()
end

--- Add a global key binding. This key binding will always be available.
--
function keybinding.add()
end

--- Remove a global key binding.
--
function keybinding.remove()
end

--- Grab keyboard and read pressed keys, calling callback function at each key
-- pressed. The callback function must return a boolean value: true to
-- continue grabbing, false to stop.
-- The function is called with 2 arguments:
-- a table containing modifiers keys and a string, the key pressed.
--
--
--
-- @param arg1 A callback function as described above.
function keygrabber.run()
end

--- Stop grabbing the keyboard.
function keygrabber.stop()
end

--- Index function of wtable objects.
-- @class table
-- @name wtable
wtable
--- Object table.
-- This table can use safely object as key.
-- @class table
-- @name otable
otable
--- awesome global table.
-- @field font The default font.
-- @field conffile The configuration file which has been loaded.
-- @class table
-- @name awesome
awesome
--- Quit awesome.
function awesome.quit()
end

--- Execute another application, probably a window manager, to replace
-- awesome.
-- @param arg1 The command line to execute.
function awesome.exec()
end

--- Spawn a program.
-- This function is multi-head (Zaphod) aware and will set display to
-- the right screen according to mouse position.
-- @param arg1 The command to launch.
-- @param arg2 The optional screen number to spawn the command on.
function awesome.spawn()
end

--- Restart awesome.
function awesome.restart()
end

--- Get or set global mouse bindings.
-- This binding will be available when you'll click on root window.
-- @param arg1 An array of mouse button bindings objects, or nothing.
function awesome.buttons()
end

--- Set default font. (DEPRECATED)
-- @param arg1 A string with a font name in Pango format.
function awesome.font_set()
end

--- Set default colors. (DEPRECATED)
--
-- @param arg1 A table with `fg' and `bg' elements, containing colors.
function awesome.colors_set()
end

--- Set default colors (DEPRECATED).
-- @param arg1 A table with `fg' and `bg' elements, containing colors.
-- @return A table with `fg' and `bg' elements, containing colors.
function awesome.colors()
end

--- Deprecated function, does nothing.
function awesome.mouse_add()
end

--- Set the function called each time a client gets focus. This function is
-- called with the client object as argument.
-- @param arg1 A function to call each time a client gets focus.
function hooks.focus()
end

--- Set the function called each time a client loses focus. This function is
-- called with the client object as argument.
-- @param arg1 A function to call each time a client loses focus.
function hooks.unfocus()
end

--- Set the function called each time a new client appears. This function is
-- called with the client object as argument.
-- @param arg1 A function to call on each new client.
function hooks.manage()
end

--- Set the function called each time a client goes away. This function is
-- called with the client object as argument.
-- @param arg1 A function to call when a client goes away.
function hooks.unmanage()
end

--- Set the function called each time the mouse enter a new window. This
-- function is called with the client object as argument.
-- @param arg1 A function to call each time a client gets mouse over it.
function hooks.mouse_enter()
end

--- Set the function called on each client's property change.
-- This function is called with the client object as argument and the
-- property name.
-- @param arg1 A function to call on each client property update.
function hooks.property()
end

--- Set the function called on each screen arrange. This function is called
-- with the screen number as argument.
-- @param arg1 A function to call on each screen arrange.
function hooks.arrange()
end

--- Set the function called on each client list change.
-- This function is called without any argument.
-- @param arg1 A function to call on each client list change.
function hooks.clients()
end

--- Set the function called on each screen tag list change.
-- This function is called with a screen number as first argument,
-- the tag object as second and the action (add or remove) as third.
-- @param arg1 A function to call on each tag list change.
function hooks.tags()
end

--- Set the function called on each client's tags change.
-- This function is called with the client and the tag as argument.
-- @param arg1 A function to call on each client's tags change.
function hooks.tagged()
end

--- Set the function to be called every N seconds.
-- @param arg1 The number of seconds to run function every. Set 0 to disable.
-- @param arg2 A function to call every N seconds (optional).
function hooks.timer()
end

--- Set the function called each time the mouse enter a new window. This
-- function is called with the client object as argument. (DEPRECATED)
-- @param arg1 A function to call each time a client gets mouse over it.
function hooks.mouseover()
end

--- Button object.
-- @field press The function called when button press event is received.
-- @field release The function called when button release event is received.
-- @class table
-- @name button
button
--- Create a new mouse button bindings.
-- @param arg1 A table with modifiers keys, or a button to clone.
-- @param arg2 A mouse button number.
-- @param arg3 A function to execute on click events.
-- @param arg4 A function to execute on release events.
-- @return A mouse button binding.
function button()
end

--- Mouse library.
-- @field coords Mouse coordinates.
-- @field screen Mouse screen number.
-- @class table
-- @name mouse
mouse
--- Deprecated
function mouse()
end

--- Get or set the mouse coords.
-- @param arg1 None or a table with x and y keys as mouse coordinates.
-- @return A table with mouse coordinates.
function mouse.coords()
end

--- A screen.
-- @field coords The screen coordinates. Immutable.
-- @field workarea The screen workarea, i.e. without wiboxes.
-- @class table
-- @name screen
screen
--- Get the screen count.
--
-- @return The screen count, at least 1.
function screen.count()
end

--- Get or set screen tags.
-- @param arg1 None or a table of tags to set to the screen.
-- The table must contains at least one tag.
function screen.tags()
end

--- Set or get the screen padding.
-- @param arg1 None or a table with new padding values.
-- @return The screen padding. A table with top, right, left and bottom
-- keys and values in pixel.
function screen.padding()
end

--- Create a new statusbar (DEPRECATED).
--
-- @param arg1 A table with optionaly defined values:
-- position, align, fg, bg, width and height.
-- @return A brand new statusbar.
function statusbar()
end

--- Wibox object.
-- @field screen Screen number.
-- @field client The client attached to this titlebar.
-- @field border_width Border width.
-- @field border_color Border color.
-- @field align The alignment.
-- @field fg Foreground color.
-- @field bg Background color.
-- @field position The position.
-- @field ontop On top of other windows.
-- @class table
-- @name wibox
wibox
--- Create a new wibox.
--
-- @param arg1 A table with optionaly defined values:
-- position, align, fg, bg, border_width, border_color, width and height.
-- @return A brand new wibox.
function wibox()
end

This function is not yet documented.

--- Tag object.
-- @field name Tag name.
-- @field screen Screen number of the tag.
-- @field layout Tag layout.
-- @field selected True if the client is selected to be viewed.
-- @field mwfact Master width factor.
-- @field nmaster Number of master windows.
-- @field ncol Number of column for slave windows.
-- @class table
-- @name tag
tag
--- Create a new tag.
--
-- @param arg1 A table with at least a name attribute.
-- Optional attributes are: mwfact, ncol, nmaster and layout.
-- @return A new tag object.
function tag()
end

--- Get or set the clients attached to this tag.
-- @param arg1 None or a table of clients to set.
-- @return A table with the clients attached to this tags.
function tag.clients()
end

--- Create a new titlebar (DEPRECATED).
--
-- @param arg1 A table with values: align, position, fg, bg, border_width,
-- border_color, width and height.
-- @return A brand new titlebar.
function titlebar()
end

--- Generic widget.
-- @field visible The widget visibility.
-- @field name The widget name.
-- @field mouse_enter A function to execute when the mouse enter the widget.
-- @field mouse_leave A function to execute when the mouse leave the widget.
-- @class table
-- @name widget
widget
--- Create a new widget.
--
-- @param arg1 A table with at least a name and a type value. Optional attributes
-- are: align.
-- @return A brand new widget.
function widget()
end

--- Get or set mouse buttons bindings to a widget.
--
-- @param arg1 An array of mouse button bindings objects, or nothing.
function widget.buttons()
end

--- Deprecated function to add mouse bindings.
function widget.mouse_add()
end

--- Image object.
-- @field width The image width.
-- @field height The image height.
-- @class table
-- @name image
image
--- Create a new image object.
-- @param arg1 The image path, or nil to create an empty image.
-- @param arg2 The image width if nil was set as first arg.
-- @param arg3 The image height if nil was set as first arg.
-- @return An image object.
function image()
end

--- Create a new image object from ARGB32 data.
-- @param arg1 The image width.
-- @param arg2 The image height.
-- @param arg3 The image data as a string in ARGB32 format.
-- @return An image object.
function image.argb32()
end

--- Rotate an image with specified angle radians and return a new image.
-- @param arg1 The angle in radians.
-- @return A rotated image.
function image.rotate()
end

--- Crop an image to the given rectangle.
-- @param arg1 The top left x coordinate of the rectangle.
-- @param arg2 The top left y coordinate of the rectangle.
-- @param arg3 The width of the rectangle.
-- @param arg4 The height of the rectangle.
-- @return A cropped image.
function image.crop()
end

--- Crop the image to the given rectangle and scales it.
-- @param arg1 The top left x coordinate of the source rectangle.
-- @param arg2 The top left y coordinate of the source rectangle.
-- @param arg3 The width of the source rectangle.
-- @param arg4 The height of the source rectangle.
-- @param arg5 The width of the destination rectangle.
-- @param arg6 The height of the destination rectangle.
-- @return A cropped image.
function image.crop_and_scale()
end

--- Graph widget.
-- @field plot_properties_set A function to set plot properties.
-- @field plot_data_add A function to add data to a plot.
-- @field height Graph height.
-- @field widget Graph width.
-- @field bg Background color.
-- @field grow Direction to grow: left or right.
-- @class table
-- @name graph
graph
--- Set various plot graph properties.
-- @param arg1 A plot name.
-- @param arg2 A table with various properties set.
function graph.plot_properties_set()
end

--- Add data to a plot.
-- @param arg1 A plot name.
-- @param arg2 A data value.
function graph.plot_data_add()
end

--- Progressbar widget.
-- @field bar_properties_set Set the properties of a bar.
-- @field bar_data_add Add data to a bar.
-- @field gap Gap betweens bars.
-- @field ticks_gap Gap between ticks.
-- @field ticks_count Number of ticks.
-- @field border_padding Border padding.
-- @field border_width Border width.
-- @field width Bars width.
-- @field height Bars height.
-- @field vertical True: draw bar vertically, false: horizontally.
-- @class table
-- @name progressbar
progressbar
--- Set various progressbar bars properties:
-- @param arg1 A bar name.
-- @param arg2 A table with keys as properties names.
function progressbar.bar_properties_set()
end

--- Add a value to a progressbar bar.
-- @param arg1 A bar name.
-- @param arg2 A data value.
function progressbar.bar_data_add()
end

--- Textbox widget.
-- @field text The text to display.
-- @field width The width of the textbox. Set to 0 for auto.
-- @field wrap The wrap mode: word, char, word_char.
-- @field ellipsize The ellipsize mode: start, middle or end.
-- @class table
-- @name textbox
textbox
--- Imagebox widget.
-- @field image The image to display.
-- @field bg The background color to use.
-- @class table
-- @name imagebox
imagebox
